% YMSC Letter format
% Koji Shimizu <shimizu@tsinghua.edu.cn>
% 2022-10-05

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ymscletter}

% Requirements
\RequirePackage{ifthen}
\RequirePackage{color}
\RequirePackage{graphicx}
\RequirePackage{geometry}

% Pass options to letter class and process
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{letter}}
\ProcessOptions
% Load Standard Letter Class
% letterpaper or a4paper recommended
\LoadClass{letter}

% Color
\definecolor{grey}{gray}{0.4}

% Variables
\newcommand{\@frominfo}{}
\newcommand{\frominfo}[1]{\renewcommand{\@frominfo}{#1}}
\frominfo{}

\newcommand{\@office}{}
\newcommand{\office}[1]{\renewcommand{\@office}{#1}}
\office{}

\newcommand{\@postcode}{}
\newcommand{\postcode}[1]{\renewcommand{\@postcode}{#1}}
\postcode{}

\newcommand{\@email}{}
\newcommand{\email}[1]{\renewcommand{\@email}{#1}}
\email{}

\newcommand{\@phone}{}
\newcommand{\phone}[1]{\renewcommand{\@phone}{#1}}
\phone{}

\newcommand{\@website}{}
\newcommand{\website}[1]{\renewcommand{\@website}{#1}}
\website{}

% Header
\newcommand{\ymschead}{
\parbox[t]{\dimexpr\linewidth-2\fboxsep-2\fboxrule}{%
\begin{center}
\hspace*{5cm}\includegraphics[height=1.6cm]{ymsclogo.eps}
\end{center}
	}}%

% Footer
\newcommand{\ymscfoot}{
\parbox[t]{\dimexpr\linewidth-2\fboxsep-2\fboxrule}{%
	\centerline{\color{grey}{\scriptsize{
	Address: \ifthenelse{\equal{\@office}{}}{Jingzhai, Tsinghua University, Haidian District, Beijing, P.R. China}{\@office}
\quad Post Code: \ifthenelse{\equal{\@postcode}{}}{100084}{\@postcode}
	}}}
	\centerline{\color{grey}{\scriptsize{
	Email: \ifthenelse{\equal{\@email}{}}{ymsc@tsinghua.edu.cn}{\@email}  \quad
	Phone: \ifthenelse{\equal{\@phone}{}}{0086-10-62773561}{\@phone} \quad	
	URL: \ifthenelse{\equal{\@website}{}}{http://ymsc.tsinghua.edu.cn}{\@website}
	}}}
	}}%

% Replace Standard Header & Footer
\providecommand{\@evenhead}{}\providecommand{\@oddhead}{}
\providecommand{\@evenfoot}{}\providecommand{\@oddfoot}{}
\renewcommand{\ps@firstpage}
	{\setlength{\headsep}{2truecm}
	\renewcommand{\@oddhead}{\ymschead}
	\renewcommand{\@oddfoot}{\ymscfoot}
	\renewcommand{\@evenhead}{}
	\renewcommand{\@evenfoot}{}}

% Replace Standard Opening
\renewcommand{\opening}[1]{
        \ifx\@empty\fromaddress
	\ifthenelse{\equal{\@frominfo}{}}{
	\thispagestyle{firstpage} % only print date (default)
	{\raggedleft\@date\par}}
	{\thispagestyle{firstpage} % print \frominfo if it is not empty
	{\@frominfo}}
	\else % home address if \address is used
	\thispagestyle{empty}%
	{\raggedleft\begin{tabular}{l@{}}\ignorespaces
		    \fromaddress \\*[2\parskip]%
		    \@date \end{tabular}\par}%
	\fi
	\vspace{2\parskip}%
	{\raggedright \toname \expandafter\\\toaddress \par}%
	\vspace{2\parskip}%
	#1\par\nobreak
	}
